Samples List - CKEditor

# CKEditor Samples List

## Basic Samples

- Replace textareas by class name
- Replace textareas by code

## Basic Customization

- Skins
- User Interface Color
- User Interface Languages

## Advanced Samples

- Replace DIV elements on the fly
- Create and destroy editor instances for Ajax applications
- Basic usage of the API
- Using the JavaScript API to customize dialogs
- Using the "Enter" key in CKEditor